<template>
    <v-dialog
        v-model="address_list"
        transition="dialog-bottom-transition"
        fullscreen
        scrollable
    >
        <v-card tile>
          <v-toolbar card dark color="#525252">
            <v-btn icon light @click="CheckProcess">
              <v-icon color="#fff">arrow_back</v-icon>
            </v-btn>

            <v-toolbar-title >{{ type }} Addresses</v-toolbar-title>
            <!-- <v-toolbar-title v-if="type == 'delivery'">Delivery Address List</v-toolbar-title> -->
            <v-spacer></v-spacer>
            <v-toolbar-items>
                <v-btn flat @click="add_new_address">
                    <i class="material-icons"> add </i> Add new
                </v-btn>
            </v-toolbar-items>
          </v-toolbar>
          <v-card-text class="p-0">
                <v-alert :value="true" type="info" outline class="m15">
                    <span>Please select {{ type }} address in order to Continue</span>
                </v-alert>

                <v-form ref="form">
                    <v-radio-group
                        v-model="addressItem"
                        class="m0 p-0 alst"
                        >
                        <v-list-tile
                            v-for="address in addresses"
                            :key="address.id_address"
                            class="_address_list"
                            >
                            <v-radio
                                :value="address.id_address"
                                :id="address.id_address"
                            ></v-radio>
                            <label
                                :for="address.id_address" class="text-capitalize">

                                    <strong class="text-uppercase" v-if="address.firstname">
                                      {{ address.firstname }} {{ address.lastname }}
                                    </strong><br>
                                    <span v-if="address.company"> {{ address.company}}, </span>
                                    <span v-if="address.address1"> {{ address.address1 }}, </span>
                                    <span v-if="address.address2"> {{ address.address2 }}, </span>
                                    <span v-if="address.city"> {{ address.city }}, </span>
                                    <span v-if="address.name"> {{ address.name }}, </span>
                                    <span v-if="address.postcode"> {{ address.postcode }} </span>
                            </label>
                        </v-list-tile>
                        <v-list-tile
                          class="_address_list"
                        >
                          <v-radio
                              value="addnew"
                              id="_addnewaddress"
                          ></v-radio>
                          <label
                          for="_addnewaddress" class="text-capitalize">
                          Add New
                        </label>
                        </v-list-tile>
                    </v-radio-group>
                </v-form>
          </v-card-text>
        </v-card>
    </v-dialog>
</template>
<script>
import axios from 'axios';
export default {
    props: ['address_list', 'order', 'type', 'addresses'],
    data () {
        return {
            address: this.addresses.id_address,
            addressItem: null,
        }
    },
    methods: {
        add_new_address: function () {
            this.order.loading = true;
            this.order.address_list = false;

            if (this.type == 'delivery') {
                this.order.loading = false;
                this.order.add_new_delivery_address = true;
            }

            if (this.type == 'invoice') {
                this.order.loading = false;
                this.order.add_new_invoice_address = true;
            }


        },
        saveSelectedAddress: function (id_address) {
            this.order.loading = true;
            var form_data = new FormData();
            form_data.append('choosenAddress', id_address);
            form_data.append('type', this.type);
            axios.post(this.$store.state.api_domain + '?comp=process&action=saveSelectedAddress', form_data, {withCredentials: true})
            .then((res) => {
                if (res.data.status == 'success') {
                    this.order.address_list = false;
                    this.order.checkOrderProcess();
                    this.addressItem = null;

                }
            });
        },
        CheckProcess: function () {
            this.order.address_list = false;
            this.order.address = [];
        }
    },
    watch: {
        addressItem: function (val) {

            if (val && val != 'addnew') {
                this.saveSelectedAddress(val);
            }

            if (val && val == 'addnew') {
                this.add_new_address();
            }
        }
    }
}
</script>
